@@ -3,12 +3,9 @@ Record Object.
 
 Physical representation of a row in a class-based object.
 """
-from collections.abc import Mapping, MutableMapping
+from collections.abc import MutableMapping, Iterator
 from typing import (
     Any,
-    List,
-    Dict,
-    Iterator,
     Union
 )
 
@@ -21,18 +18,18 @@ class Record(MutableMapping):
       params:
           row: any resultset
     """
-    __slots__ = '_row', '_columns'
+    __slots__ = ('_row', '_columns')
 
-    def __init__(self, row: Any, columns: List = []):
+    def __init__(self, row: Any, columns: list = None):
         self._row = row
         self._columns = columns
 
-    def result(self, key):
+    def result(self, key: Union[str, Any]) -> Any:
         if self._row:
             try:
                 return self._row[key]
             except KeyError:
-                print("Error on key: %s " % key)
+                print(f"Error on key: {key}")
                 return None
         else:
             return None
@@ -41,7 +38,7 @@ class Record(MutableMapping):
         return self._row
 
     @classmethod
-    def from_dict(cls, row: Dict) -> "Record":
+    def from_dict(cls, row: dict) -> "Record":
         return cls(row = row, columns = row.keys())
         # keys, values = zip(*row.items())
         # return cls(row = values, columns = [[name] for name in keys])
@@ -50,19 +47,16 @@ class Record(MutableMapping):
     def row(self) -> Any:
         return self._row
 
-    def columns(self) -> List:
+    def columns(self) -> list:
         return self._columns
 
     def items(self) -> zip:  # type: ignore
         return zip(self._columns, self._row)
 
-    @property
-    def keys(self) -> List:
+    def keys(self) -> list:
         return self._columns
 
-    """
-     Section: Simple magic methods
-    """
+### Section: Simple magic methods
     def __len__(self) -> int:
         return len(self._row)
 
@@ -87,9 +81,10 @@ class Record(MutableMapping):
             return self._row[key]
         except (KeyError, TypeError):
             return False
-        
-    def __setitem__(self, key: Union[str, int], value: Any) -> Any:
+
+    def __setitem__(self, key: Union[str, Any], value: Any) -> None:
         # optional processing here
+        self._row[key] = value
         super(Record, self).__setitem__(key, value)
 
     def __getattr__(self, attr: str) -> Any:
@@ -99,14 +94,14 @@ class Record(MutableMapping):
         if self._row:
             try:
                 return self._row[attr]
-            except KeyError:
+            except KeyError as err:
                 raise KeyError(
                     f"Record Error: invalid column name {attr} on {self._row!r}"
-                )
-            except TypeError:
+                ) from err
+            except TypeError as err:
                 raise TypeError(
                     f"Record Error: invalid Result on {self._row!r} for {attr}"
-                )
+                ) from err
         else:
             return False
 
