@@ -7,6 +7,9 @@ and work with Data in the same way, no matter which is the DB Backend.
 
 AsyncDB Models are based on python Dataclasses and type annotations.
 """
-from .base import Field, Column, Model
+from dataclasses import is_dataclass
+from datamodel import Field, Column
+from .model import Model, is_missing
 
-__all__ = ['Field', 'Column', 'Model', ]
\ No newline at end of file
+
+__all__ = ('Field', 'Column', 'Model', 'is_dataclass', 'is_missing', )
